@@ -1,4 +1,5 @@
 import atexit
+import inspect
 import logging
 from typing import (
     Any,
@@ -104,9 +105,6 @@ class ComponentInstance:
     def __exit__(self, exc_type, exc_value, traceback) -> None:  # type: ignore
         self.shutdown()
 
-    def __del__(self) -> None:
-        self.shutdown()
-
     @property
     def instance_name(self) -> str:
         """Component name with a random phrase to represent
@@ -121,6 +119,40 @@ class ComponentInstance:
         or a user-defined ID."""
         return self._instance_name.split("__")[-1]
 
+    def close(self, wait_for_logging_threads: bool = False) -> None:
+        """Alias for shutdown.
+
+        Usage:
+        ```python
+        from motion import Component
+
+        C = Component("MyComponent")
+
+        @C.init_state
+        def setUp():
+            return {"value": 0}
+
+        # Define serve and update operations
+
+        if __name__ == "__main__":
+            c_instance = C()
+            c_instance.run(...)
+            c_instance.run(...)
+            c_instance.close()
+
+            # Or, use a context manager
+            with C() as c_instance:
+                c_instance.run(...)
+                c_instance.run(...)
+        ```
+
+        Args:
+            wait_for_logging_threads (bool, optional): Defaults to False.
+        """
+
+        # Call shutdown
+        self.shutdown(wait_for_logging_threads=wait_for_logging_threads)
+
     def shutdown(self, wait_for_logging_threads: bool = False) -> None:
         """Shuts down a Motion component instance, saving state.
         Automatically called when the instance is garbage collected.
@@ -149,11 +181,14 @@ class ComponentInstance:
                 c_instance.run(...)
         ```
         """
-        if self.disable_update_task:
-            return
 
-        if not self.running:
-            return
+        caller_frame = inspect.currentframe().f_back  # type: ignore
+        if caller_frame is not None:
+            logger.debug(
+                f"Caller: {caller_frame.f_code.co_name} in {caller_frame.f_code.co_filename}"
+            )
+        else:
+            logger.debug("No caller frame available. Unable to trace the caller.")
 
         # Flush the update queue
         if self.flush_on_exit:
